Skabe tilgængeligt indhold

Skabe tilgængeligt indhold | TOC

TinyMCE kan producere HTML, der vil være tilgængeligt for alle brugere, også dem med handicaps, som anvender forskellige hjælpeteknikker. Den kan også skabe indhold, der er tilgængeligt for brugere, som anvender tekstbaserede browsere eller dem, der browser uden at vise billederne frem på siderne.

Ting du selv kan gøre, for at gøre dine tekste tilgængelige:

1. Lav en billedbeskrivelse: Blinde brugere eller andre, som ikke er i stand til at se billeder, er helt afhængige af billedbeskrivelsen eller alt-teksten, som erstatter selve billedet. Hvis et billede ingen betydning har - dvs. hvis det blot fungerer som dekoration eller som et blankt område, så lad billedbeskrivelsen stå tom. Så vil TinyMCE indsætte et tomt alt-felt, der vil tvinge hjælpeprogrammerne til at ignorere billedet.
2. Tilføj udstrækning til en tabels overskriftsceller: I den dialog, som gør det muligt at styre en tabels attributter, bør man angive en overskrifts udstrækning. Det vil fungere sådan, at overskriften automatisk knyttes til alle værdier i tabellen, hvilket gør det nemmere for blinde brugere at forstå, hvad indholdet i den enkelte celle betyder.
3. Strukturer indholdet med fornuftige overskrifter: Vælg standardformaterede overskrifter (som f. eks. H1-6) for at lave overskrifter til dit indhold - går det i stedet for at lave dine egne standarder. Blinde brugere anvender en læser, der kan genkende disse standardformater og på den måde lave en indholdsfortegnelse over siden. På den måde kan en blind bruger lettere bevæge sig rundt på siden og springe fra afsnit til afsnit.
4. Husk at lave alternativt indhold: Lav en alternativ side der repræsenterer ikke-HTML-formateret indhold - så som Flash, Java applets eller indlejrede videosekvenser. Denne kan laves som et stykke statisk grafik kombineret med en beskrivelse af billedet og en beskrivelse af det indhold, som ville være dukket op, hvis man havde set siden på normal vis. En alternativ HTML-side kan også laves, hvorefter man så kan lægge et link på til den ved siden af Falsh-referencen eller referencen til Java appletten. På denne måde sikrer du, at indholdet også er tilgængeligt for folk, som bruger hjælpeteknologier, som ikke er i stand til at vise eller afvikle dit indhold eller som mangler den relevante player eller plugin.
5. Kontroller tilgængeligheden: Når AChecker plugin'en er installeret sammen med TinyMCE, kan du blot trykke på den relevante knap for at blive adviseret om mulige tilgængelighedsproblemer.

Besøg ACheckers hjemmeside for at se yderligere informationer om, hvordan man skaber indhold, som alle brugere kan tilgå.

Tilbage til: Indholdsfortegnelse | Top